@@ -114,7 +114,7 @@ void EstateDetails::paintEvent(TQPaintEvent *)
 		TQColor greenHouse(0, 255, 0);
 		TQColor redHotel(255, 51, 51);
 		TQPainter painter;
-		painter.begin(TQT_TQPAINTDEVICE(m_pixmap), this);
+		painter.begin(m_pixmap, this);
 
 		painter.setPen(TQt::black);
 
@@ -136,7 +136,7 @@ void EstateDetails::paintEvent(TQPaintEvent *)
 			quartzBuffer->resize(25, (height()/4)-2);
 
 			TQPainter quartzPainter;
-			quartzPainter.begin(TQT_TQPAINTDEVICE(quartzBuffer), this);
+			quartzPainter.begin(quartzBuffer, this);
 
 			painter.setBrush(titleColor);
 			painter.drawRect(0, 0, width(), titleHeight);
@@ -258,7 +258,7 @@ void EstateDetails::addButton(TQString command, TQString caption, bool enabled)
 	button->setEnabled(enabled);
 	button->show();
 
-	connect(button, TQT_SIGNAL(pressed()), this, TQT_SLOT(buttonPressed()));
+	connect(button, TQ_SIGNAL(pressed()), this, TQ_SLOT(buttonPressed()));
 }
 
 void EstateDetails::addCloseButton()
@@ -268,7 +268,7 @@ void EstateDetails::addCloseButton()
 		m_closeButton = new KPushButton(KStdGuiItem::close(), this);
 		m_buttonBox->addWidget(m_closeButton);
 		m_closeButton->show();
-		connect(m_closeButton, TQT_SIGNAL(pressed()), this, TQT_SIGNAL(buttonClose()));
+		connect(m_closeButton, TQ_SIGNAL(pressed()), this, TQ_SIGNAL(buttonClose()));
 	}
 }
 
