@@ -30,7 +30,7 @@
 
 class KGrCanvas : public TQCanvasView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KGrCanvas (TQWidget * parent = 0, const char *name = 0);
