@@ -119,10 +119,10 @@ GameBoard::GameBoard( TQWidget *parent )
     //**********************************************************************
     // Set up signal/slot connections
     //**********************************************************************
-    connect( mapWidget, TQT_SIGNAL( planetSelected(Planet *) ), this, TQT_SLOT(planetSelected(Planet *)) );
-    connect( shipCountEdit, TQT_SIGNAL(returnPressed()), this, TQT_SLOT(newShipCount()) );
-    connect( endTurn, TQT_SIGNAL( clicked() ), this, TQT_SLOT( nextPlayer() ) );
-    connect( mapWidget, TQT_SIGNAL( planetHighlighted(Planet *)), planetInfo, TQT_SLOT(showPlanet(Planet *)) );
+    connect( mapWidget, TQ_SIGNAL( planetSelected(Planet *) ), this, TQ_SLOT(planetSelected(Planet *)) );
+    connect( shipCountEdit, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(newShipCount()) );
+    connect( endTurn, TQ_SIGNAL( clicked() ), this, TQ_SLOT( nextPlayer() ) );
+    connect( mapWidget, TQ_SIGNAL( planetHighlighted(Planet *)), planetInfo, TQ_SLOT(showPlanet(Planet *)) );
 
     changeGameBoard( false );
 }
