@@ -4,7 +4,7 @@
 #include "int_validator.moc"
 
 IntValidator::IntValidator( TQWidget *parent, const char *name ) :
-    TQValidator( TQT_TQOBJECT(parent), name )
+    TQValidator( parent, name )
 {
 #ifdef INT_MIN
     v_bottom = INT_MIN;
@@ -15,7 +15,7 @@ IntValidator::IntValidator( TQWidget *parent, const char *name ) :
 }
 
 IntValidator::IntValidator( int bottom, int top, TQWidget *parent, const char *name ) :
-TQValidator( TQT_TQOBJECT(parent), name )
+TQValidator( parent, name )
 {
     v_bottom = bottom;
     v_top = top;
