@@ -8,7 +8,7 @@ class Deck;
 class TDEMainWindow;
 
 class Kings : public FreecellBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
