@@ -61,7 +61,7 @@ const unsigned HIGHSCORE_MAX = 10;
 
 class App : public TDEMainWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
