@@ -6,7 +6,7 @@
 
 class KSGameConfig : public GameConfig
 {
-    Q_OBJECT
+    TQ_OBJECT
   
  public:
     KSGameConfig();
