@@ -299,8 +299,8 @@ bool BaseBoard::timeout()
     Q_ASSERT( graphic() );
     if ( state==GameOver ) return true;
 	switch (state) {
-        case BeforeRemove: _beforeRemove(FALSE); break;
-        case AfterRemove:  _afterRemove(FALSE);  break;
+        case BeforeRemove: _beforeRemove(false); break;
+        case AfterRemove:  _afterRemove(false);  break;
         default:           return false;
 	}
 	main->update();
